@@ -15,7 +15,7 @@ class BaseRepository(implements(InterfaceBaseRepository)):
             query: Query,
     ) -> list[T]:
         """
-        Execute query
+        Выполнение запроса
         """
         items: T = query.firebase_query.get()
         return [
@@ -23,6 +23,15 @@ class BaseRepository(implements(InterfaceBaseRepository)):
             for item in items
         ]
 
+    def get_by_id(
+            self,
+            item_id: str
+    ) -> Query:
+        """
+        Получение по id
+        """
+        return self.model.collection.get(item_id)
+
     def get_by_field(
             self,
             field: str,
@@ -31,7 +40,7 @@ class BaseRepository(implements(InterfaceBaseRepository)):
             query: Query = None
     ) -> Query:
         """
-        Get by field
+        Получение по полю
         """
         if query:
             query.where(field, operator, value)
@@ -40,4 +49,7 @@ class BaseRepository(implements(InterfaceBaseRepository)):
         return query
 
     def update(self, item: T) -> T:
+        """
+        Обновление
+        """
         return item.update()
